/*
 *
 *
 *    settings.h
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2016-2017 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *
 *
 */


#ifndef __KK5JY_RTTY_SETTINGS_H
#define __KK5JY_RTTY_SETTINGS_H

// settings block (will be persisted)
struct SettingsBlock {
	// PTT lead-in (in msec)
	unsigned long pttLeadIn;

	// PTT lead-out (in msec)
	unsigned long pttLeadOut;

	// the revarsal setting
	Reversals reverse;

	// the encoding
	Encodings encoding;

	// the squelch setting
	uint8_t squelch;

	// the squelch timeout (in msec)
	uint32_t squelch_timeout;

	// the line-input level
	uint8_t line_input;

	// default ctor
	SettingsBlock() {
		pttLeadIn = 250;
		pttLeadOut = 250;
		reverse = RevNone;
		encoding = Baudot;
		squelch = 80;
		squelch_timeout = 1000;
		line_input = 0;
	}

	// copy ctor
	SettingsBlock(const SettingsBlock &sb) {
		pttLeadIn = sb.pttLeadIn;
		pttLeadOut = sb.pttLeadOut;
		reverse = sb.reverse;
		encoding = sb.encoding;
		squelch = sb.squelch;
		squelch_timeout = sb.squelch_timeout;
		line_input = sb.line_input;
	}

	// operator =
	SettingsBlock &operator = (const SettingsBlock &sb) {
		pttLeadIn = sb.pttLeadIn;
		pttLeadOut = sb.pttLeadOut;
		reverse = sb.reverse;
		encoding = sb.encoding;
		squelch = sb.squelch;
		squelch_timeout = sb.squelch_timeout;
		line_input = sb.line_input;
		return (*this);
	}
};

#endif
